@@ -12,7 +12,9 @@ __all__ = (
 
     'DEFAULT_MAX_LENGTH', 'FORM_HANDLER_PLUGINS_EXECUTION_ORDER',
     'FAIL_ON_MISSING_FORM_ELEMENT_PLUGINS',
-    'FAIL_ON_MISSING_FORM_HANDLER_PLUGINS'
+    'FAIL_ON_MISSING_FORM_HANDLER_PLUGINS',
+    'FAIL_ON_ERRORS_IN_FORM_ELEMENT_PLUGINS',
+    'FAIL_ON_ERRORS_IN_FORM_HANDLER_PLUGINS',
 
     'WAIT_BETWEEN_TEST_STEPS', 'WAIT_AT_TEST_END',
 )
@@ -78,6 +80,8 @@ FORM_HANDLER_PLUGINS_EXECUTION_ORDER = (
 
 FAIL_ON_MISSING_FORM_ELEMENT_PLUGINS = True
 FAIL_ON_MISSING_FORM_HANDLER_PLUGINS = True
+FAIL_ON_ERRORS_IN_FORM_ELEMENT_PLUGINS = False
+FAIL_ON_ERRORS_IN_FORM_HANDLER_PLUGINS = False
 
 # **************************************************************
 # **************************************************************
